@@ -1,7 +1,7 @@
-#! /bin/sh
+#! /usr/bin/env bash
 
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2018,2019,2025 Janneke Nieuwenhuizen <janneke@gnu.org>
 #
 # This file is part of GNU Mes.
 #
@@ -94,7 +94,12 @@ if [ -f "$b".exit ]; then
 else
     e=0
 fi
-[ $r = $e ] || exit 1
+if [ $r != $e ]; then
+    if [ $r != 0 ]; then
+        exit $r;
+    fi
+    exit 1
+fi
 if [ -f "$b".stdout ]; then
     $DIFF -ub "$b".stdout "$o".1
 fi
