@@ -1,5 +1,5 @@
 ;;; GNU Mes --- Maxwell Equations of Software
-;;; Copyright © 2016,2017,2018,2019,2020,2021,2022,2023,2024 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2016,2017,2018,2019,2020,2021,2022,2023,2024,2025 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2023 Ekaitz Zarraga <ekaitz@elenq.tech>
 ;;;
 ;;; This file is part of GNU Mes.
@@ -42,6 +42,7 @@
   #:use-module (gnu packages perl)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages texinfo)
+  #:use-module (gnu packages time)
   #:use-module (guix build-system gnu)
   #:use-module (guix build-system trivial)
   #:use-module (guix gexp)
@@ -56,14 +57,14 @@
 (define-public mescc-tools
   (package
     (name "mescc-tools")
-    (version "1.5.2")
+    (version "1.7.0")
     (source (origin
               (method url-fetch)
               (uri (string-append "mirror://savannah/" name "/"
                                   name "-" version ".tar.gz"))
               (sha256
                (base32
-                "1jak61gxab8bj8ddpgwfn9lqs917szq1phadmg8y5cjsndn1hv4k"))))
+                "0p2pnvci9vglmf7zas12ay2v5gnrwafqsqqw1dfyb2bgayzzg0mn"))))
     (build-system gnu-build-system)
     (supported-systems '("i686-linux" "x86_64-linux"
                          "armhf-linux" "aarch64-linux"
@@ -87,7 +88,7 @@ get_machine.")
 (define-public m2-planet
   (package
     (name "m2-planet")
-    (version "1.11.0")
+    (version "1.12.0")
     (source (origin
               (method url-fetch)
               (uri (string-append
@@ -95,7 +96,7 @@ get_machine.")
                     "Release_" version "/" name "-" version ".tar.gz"))
               (sha256
                (base32
-                "1c510p55amxjyvjlx9jpa30gixlgmf6mmfnaqcs46412krymwg38"))))
+                "16vgad5wa5lmh6mjnkid4qn2xs7hfcfn43z9gd8iljzvsxl2i8z7"))))
     (native-inputs (list mescc-tools))
     (build-system gnu-build-system)
     (supported-systems '("i686-linux" "x86_64-linux"
@@ -379,20 +380,96 @@ $prefix/share/guile/site/$GUILE_EFFECTIVE_VERSION\n")))))
 $prefix/share/guile/site/$GUILE_EFFECTIVE_VERSION\n")))))
     (inputs (list guile-3.0))))
 
+(define-public nyacc-1.09.5
+  (package
+    (inherit nyacc-0.99)
+    (version "1.09.5")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://savannah/nyacc/nyacc-"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "12l6xmbvvmam55jzdqisrd7cnb4qfxk2g1aa3gxmk32r3sb57kb0"))
+              (modules '((guix build utils)))
+              (snippet
+               '(substitute* "configure"
+                  (("GUILE_GLOBAL_SITE=\\$prefix.*")
+                   "GUILE_GLOBAL_SITE=\
+$prefix/share/guile/site/$GUILE_EFFECTIVE_VERSION\n")))))
+    (inputs (list guile-3.0))))
+
+(define-public nyacc-2.00.0
+  (package
+    (inherit nyacc-0.99)
+    (version "2.00.0")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://savannah/nyacc/nyacc-"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "08ssi79dpwhvkfbll02z6bx67r3xgnxvlkrnqir4d08m4fbid6h8"))
+              (modules '((guix build utils)))
+              (snippet
+               '(substitute* "configure"
+                  (("GUILE_GLOBAL_SITE=\\$prefix.*")
+                   "GUILE_GLOBAL_SITE=\
+$prefix/share/guile/site/$GUILE_EFFECTIVE_VERSION\n")))))
+    (inputs (list guile-3.0))))
+
+(define-public nyacc-2.00.6
+  (package
+    (inherit nyacc-0.99)
+    (version "2.00.6")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://savannah/nyacc/nyacc-"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "05397dqxv6sargkmz8kbgbrjvwcjrqcqc91bkmfxgmwm4a9sdg6i"))
+              (modules '((guix build utils)))
+              (snippet
+               '(substitute* "configure"
+                  (("GUILE_GLOBAL_SITE=\\$prefix.*")
+                   "GUILE_GLOBAL_SITE=\
+$prefix/share/guile/site/$GUILE_EFFECTIVE_VERSION\n")))))
+    (inputs (list guile-3.0))))
+
+(define-public nyacc-2.02.2
+  (package
+    (inherit nyacc-0.99)
+    (version "2.02.2")
+    (source (origin
+              (method url-fetch)
+              (uri (string-append "mirror://savannah/nyacc/nyacc-"
+                                  version ".tar.gz"))
+              (sha256
+               (base32
+                "01829c24v531036rj8grcwx4hmiy3f0jznc9zbfa4wrslmq566k9"))
+              (modules '((guix build utils)))
+              (snippet
+               '(substitute* "configure"
+                  (("GUILE_GLOBAL_SITE=\\$prefix.*")
+                   "GUILE_GLOBAL_SITE=\
+$prefix/share/guile/site/$GUILE_EFFECTIVE_VERSION\n")))))
+    (inputs (list guile-3.0))))
+
 (define-public mes
   (package
     (name "mes")
-    (version #!mes!# "0.26.2")
+    (version #!mes!# "0.27")
     (source (origin
               (method url-fetch)
               (uri (string-append
                     "https://ftp.gnu.org/pub/gnu/mes/mes-" version ".tar.gz"))
               (sha256
-               (base32 #!mes!# "120a7ljnyi9127inaarlqv6cl98cmk72s3gmyad7cjrwy6cvzf1g"))))
+               (base32 #!mes!# "1a5ag8i303yhf76sg05rpcans9vadvnpxcpa4sl09z4cv5bfcgh3"))))
     (build-system gnu-build-system)
     (supported-systems '("aarch64-linux" "armhf-linux" "i686-linux"
                          "x86_64-linux" "riscv64-linux"))
-    (propagated-inputs (list mescc-tools nyacc-1.09.4))
+    (propagated-inputs (list mescc-tools nyacc-2.02.2))
     (native-inputs
      (append
       (list guile-3.0)
@@ -418,15 +495,15 @@ $prefix/share/guile/site/$GUILE_EFFECTIVE_VERSION\n")))))
      `(#:strip-binaries? #f)) ; binutil's strip b0rkes MesCC/M1/hex2 binaries
     (native-search-paths
      (list (search-path-specification
-            (variable "C_INCLUDE_PATH")
-            (files '("include")))
+             (variable "C_INCLUDE_PATH")
+             (files '("include")))
            (search-path-specification
-            (variable "LIBRARY_PATH")
-            (files '("lib")))
+             (variable "LIBRARY_PATH")
+             (files '("lib")))
            (search-path-specification
-            (variable "MES_PREFIX")
-            (separator #f)
-            (files '("")))))
+             (variable "MES_PREFIX")
+             (separator #f)
+             (files '("")))))
     (synopsis "Scheme interpreter and C compiler for full source bootstrapping")
     (description
      "GNU Mes--Maxwell Equations of Software--brings the Reduced Binary Seed
@@ -438,7 +515,7 @@ Guile.")
     (license gpl3+)))
 
 (define-public mes.git
-  (let ((version #!mes!# "0.26.2")
+  (let ((version #!mes!# "0.27")
         (revision "0")
         (commit (read-string (open-pipe "git show HEAD | head -1 | cut -d ' ' -f 2" OPEN_READ))))
     (package
@@ -450,4 +527,5 @@ Guile.")
                           #:select? (git-predicate %source-dir)))
       (native-inputs
        `(("gdb" ,gdb)
+         ("time" ,time)
          ,@(package-native-inputs mes))))))
