@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,20225 janneke Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -35,7 +35,6 @@ void *memchr (void const *block, int c, size_t size);
 void *memcpy (void *dest, void const *src, size_t n);
 void *memmove (void *dest, void const *src, size_t n);
 void *memset (void *s, int c, size_t n);
-void *memchr (void const *block, int c, size_t size);
 int memcmp (void const *s1, void const *s2, size_t n);
 void *memmem (void const *haystack, int haystack_len, void const *needle, int needle_len);
 char *strcat (char *dest, char const *src);
@@ -43,17 +42,20 @@ char *strchr (char const *s, int c);
 int strcasecmp (char const *s1, char const *s2);
 int strcmp (char const *, char const *);
 char *strcpy (char *dest, char const *src);
+size_t strcspn (char const *string, char const *stopset);
 size_t strlen (char const *);
+char *strncat (char *to, char const *from, size_t size);
 char *strncpy (char *to, char const *from, size_t size);
 int strncmp (char const *, char const *, size_t);
+char *strpbrk (char const *string, char const *stopset);
 char *strrchr (char const *s, int c);
+size_t strspn (char const *string, char const *skipset);
 char *strstr (char const *haystack, char const *needle);
 char *strlwr (char *string);
 char *strupr (char *string);
 
 
 char *strerror (int errnum);
-void perror (char const *message);
 
 #endif // ! SYSTEM_LIBC
 
