@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2018,2019,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
  *
  * This file is part of GNU Mes.
  *
@@ -21,9 +22,16 @@
 #include <linux/syscall.h>
 #include <arch/syscall.h>
 #include <unistd.h>
+#include <fcntl.h>
 
 int
 rename (char const *old_name, char const *new_name)
 {
+#if defined (SYS_rename)
   return _sys_call2 (SYS_rename, (long) old_name, (long) new_name);
+#elif defined (SYS_renameat2)
+  return _sys_call5 (SYS_renameat2, AT_FDCWD, (long) old_name, AT_FDCWD, (long) new_name, 0);
+#else
+#error No usable rename syscall
+#endif
 }
