@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,17 +18,22 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
 #include <linux/syscall.h>
 #include <arch/syscall.h>
 #include <sys/types.h>
+#include <sys/wait.h>
 
 pid_t
 waitpid (pid_t pid, int *status_ptr, int options)
 {
-#if __i386__
-  return _sys_call3 (SYS_waitpid, (long) pid, (long) status_ptr, (int) options);
-#elif __x86_64__ || __arm__
-  return _sys_call4 (SYS_wait4, (long) pid, (long) status_ptr, (int) options, 0);
+  long long_pid = pid;
+  long long_status_ptr = cast_voidp_to_long (status_ptr);
+  long long_options = options;
+#if defined (SYS_waitpid)
+  return _sys_call3 (SYS_waitpid, long_pid, long_status_ptr, long_options);
+#elif defined (SYS_wait4)
+  return wait4 (pid, status_ptr, options, 0);
 #else
 #error arch not supported
 #endif
