@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -32,14 +32,3 @@ ioctl (int filedes, unsigned long command, ...)
   errno = 0;
   return 0;
 }
-
-int
-ioctl3 (int filedes, unsigned long command, long data)
-{
-  static int stub = 0;
-  if (__mes_debug () && !stub)
-    eputs ("ioctl3 stub\n");
-  stub = 1;
-  errno = 0;
-  return 0;
-}
