@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2018,2025 Janneke Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -25,7 +25,7 @@
 size_t
 strspn (char const *string, char const *skipset)
 {
-  char *p = string;
+  char *p = (char*)string;
   while (*p)
     if (!strchr (skipset, *p))
       break;
