@@ -80,6 +80,6 @@
     ((_ v (unquote var) kt kf) (let ((var v)) kt))
     ((_ v (x . y) kt kf)
      (if (pair? v)
-         (ppat (pmatch-car v) x (ppat (pmatch-cdr v) y kt kf) kf)
+         (ppat (car v) x (ppat (cdr v) y kt kf) kf)
          kf))
     ((_ v lit kt kf) (if (eq? v (quote lit)) kt kf))))
