@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2019,2020,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019,2020,2022,2025 Janneke Nieuwenhuizen <janneke@gnu.org>
  * Copyright © Timothy Sample 2022 <samplet@ngyro.com>
  *
  * This file is part of GNU Mes.
@@ -148,7 +148,7 @@ set_x (struct scm *x, struct scm *e, int define_p)
 }
 
 struct scm *
-call_lambda (struct scm *e, struct scm *x, struct scm *aa, struct scm *a)       /*:((internal)) */
+call_lambda (struct scm *e, struct scm *x, struct scm *aa)       /*:((internal)) */
 {
   struct scm *cl = cons (cons (cell_closure, x), x);
   R1 = e;
@@ -338,7 +338,7 @@ expand_variable_ (int top_p)        /*:((internal)) */
                    && a != cell_symbol_current_environment
                    && formal_p (a, R2) == 0)
             {
-              v = lookup_binding (R1->car, cell_f);
+              v = lookup_binding (a, cell_f);
               if (v != cell_f)
                 R1->car = v;
               else
@@ -346,7 +346,7 @@ expand_variable_ (int top_p)        /*:((internal)) */
                   /* Lookup the binding again, but this time make a
                      local definition in case the name becomes bound in
                      the future. */
-                  R1->car = lookup_binding (R1->car, cell_t);
+                  R1->car = lookup_binding (a, cell_t);
                 }
             }
         }
@@ -468,8 +468,6 @@ eval_apply:
     goto macro_expand;
   else if (R3 == cell_vm_macro_expand_lambda)
     goto macro_expand_lambda;
-  else if (R3 == cell_vm_eval_pmatch_car)
-    goto eval_pmatch_car;
   else if (R3 == cell_vm_begin_expand_macro)
     goto begin_expand_macro;
   else if (R3 == cell_vm_macro_expand_define)
@@ -480,8 +478,6 @@ eval_apply:
     goto call_with_current_continuation2;
   else if (R3 == cell_vm_macro_expand_set_x)
     goto macro_expand_set_x;
-  else if (R3 == cell_vm_eval_pmatch_cdr)
-    goto eval_pmatch_cdr;
   else if (R3 == cell_vm_macro_expand_define_macro)
     goto macro_expand_define_macro;
   else if (R3 == cell_vm_evlis)
@@ -541,7 +537,7 @@ apply:
       aa = aa->cdr;
       check_formals (R1->car, formals, R1->cdr);
       p = pairlis (formals, args, aa);
-      call_lambda (body, p, aa, R0);
+      call_lambda (body, p, aa);
       goto begin;
     }
   else if (t == TCONTINUATION)
@@ -554,10 +550,8 @@ apply:
             g_stack_array[STACK_SIZE - v->length + i] = vector_ref_ (v, i);
           g_stack = STACK_SIZE - v->length;
         }
-      x = R1;
-      gc_pop_frame ();
-      R1 = x->cdr->car;
-      goto eval_apply;
+      R1 = R1->cdr->car;
+      goto vm_return;
     }
   else if (t == TSPECIAL)
     {
@@ -608,7 +602,7 @@ apply:
           body = R1->car->cdr->cdr;
           p = pairlis (formals, R1->cdr, R0);
           check_formals (R1, formals, args);
-          call_lambda (body, p, p, R0);
+          call_lambda (body, p, p);
           goto begin;
         }
     }
@@ -639,33 +633,10 @@ eval:
         }
 
       c = R1->car;
-
-      if (c == cell_symbol_pmatch_car)
+      if (c == cell_symbol_quote)
         {
-          push_cc (R1->cdr->car, R1, R0, cell_vm_eval_pmatch_car);
-          goto eval;
-        eval_pmatch_car:
-          x = R1;
-          gc_pop_frame ();
-          R1 = x->car;
-          goto eval_apply;
-        }
-      else if (c == cell_symbol_pmatch_cdr)
-        {
-          push_cc (R1->cdr->car, R1, R0, cell_vm_eval_pmatch_cdr);
-          goto eval;
-        eval_pmatch_cdr:
-          x = R1;
-          gc_pop_frame ();
-          R1 = x->cdr;
-          goto eval_apply;
-        }
-      else if (c == cell_symbol_quote)
-        {
-          x = R1;
-          gc_pop_frame ();
-          R1 = x->cdr->car;
-          goto eval_apply;
+          R1 = R1->cdr->car;
+          goto vm_return;
         }
       else if (c == cell_symbol_begin)
         goto begin;
@@ -716,16 +687,14 @@ eval:
                       name = name->car;
                     if (macro_p != 0)
                       {
-                        entry = assq (name, g_macros);
+                        entry = macro_get_handle (name);
                         if (entry == cell_f)
                           macro_set_x (name, cell_f);
                       }
                     else
-                      {
-                        /* Ensure this name is bound in the current
-                           module. */
-                        lookup_binding (name, cell_t);
-                      }
+                      /* Ensure this name is bound in the current
+                         module. */
+                      lookup_binding (name, cell_t);
                   }
                 R2 = R1;
                 aa = R1->cdr->car;
@@ -846,17 +815,6 @@ macro_expand:
       goto vm_return;
     }
 
-  if (R1->type == TPAIR)
-    {
-      macro = get_macro (R1->car);
-      if (macro != cell_f)
-        {
-          R1 = cons (macro, R1->cdr);
-          push_cc (R1, cell_nil, R0, cell_vm_macro_expand);
-          goto apply;
-        }
-    }
-
   if (R1->car == cell_symbol_define || R1->car == cell_symbol_define_macro)
     {
       push_cc (R1->cdr->cdr, R1, R0, cell_vm_macro_expand_define);
@@ -884,27 +842,31 @@ macro_expand:
       goto vm_return;
     }
 
-  if (R1->type == TPAIR)
+  macro = get_macro (R1->car);
+  if (macro != cell_f)
     {
-      a = R1->car;
-      if (a->type == TSYMBOL && a != cell_symbol_begin)
+      R1 = cons (macro, R1->cdr);
+      push_cc (R1, cell_nil, R0, cell_vm_macro_expand);
+      goto apply;
+    }
+  a = R1->car;
+  if (a->type == TSYMBOL && a != cell_symbol_begin)
+    {
+      macro = macro_get_handle (cell_symbol_portable_macro_expand);
+      if (macro != cell_f)
         {
-          macro = macro_get_handle (cell_symbol_portable_macro_expand);
-          if (macro != cell_f)
+          expanders = lookup_value (cell_symbol_sc_expander_alist);
+          if (expanders != cell_undefined)
             {
-              expanders = lookup_value (cell_symbol_sc_expander_alist);
-              if (expanders != cell_undefined)
+              macro = assq (R1->car, expanders);
+              if (macro != cell_f)
                 {
-                  macro = assq (R1->car, expanders);
-                  if (macro != cell_f)
+                  sc_expand = lookup_value (cell_symbol_macro_expand);
+                  R2 = R1;
+                  if (sc_expand != cell_undefined && sc_expand != cell_f)
                     {
-                      sc_expand = lookup_value (cell_symbol_macro_expand);
-                      R2 = R1;
-                      if (sc_expand != cell_undefined && sc_expand != cell_f)
-                        {
-                          R1 = cons (sc_expand, cons (R1, cell_nil));
-                          goto apply;
-                        }
+                      R1 = cons (sc_expand, cons (R1, cell_nil));
+                      goto apply;
                     }
                 }
             }
@@ -1068,7 +1030,7 @@ vm_return:
 struct scm *
 apply (struct scm *f, struct scm *x, struct scm *a)     /*:((internal)) */
 {
-  push_cc (cons (f, x), cell_unspecified, R0, cell_unspecified);
+  push_cc (cons (f, x), cell_unspecified, a, cell_unspecified);
   R3 = cell_vm_apply;
   return eval_apply ();
 }
